@@ -258,6 +258,9 @@ class ResponseObject(object):
 			if isinstance(value, object):
 				dictionary[key] = str(value)
 			else:
+				if value == "True": value = True
+				if value == "False": value = False
+				if value == "None": value = None
 				dictionary[key] = value
 		return dictionary
 	# assign self variables by dictionary.
@@ -290,6 +293,7 @@ class ResponseObject(object):
 		else:
 			return json.dumps(self.dict(), indent=4)
 	def json(self,):
+		return self.dictionary(serializable=True)
 		return json.dumps(self)
 		return json.dumps(self, default=lambda o: o.__dict__)
 	#def __dict__(self):
